%define anolis_release 5

%bcond_with     debug
%bcond_without  testsuite

%global __cmake_in_source_build 1

Name:           mariadb-connector-c
Summary:        The MariaDB Native Client library (C driver)
Version:        3.2.7
Release:        %{anolis_release}%{?dist}
License:        LGPLv2+
Url:            http://mariadb.org/
Source:         https://downloads.mariadb.org/interstitial/connector-c-%{version}/%{name}-%{version}-src.tar.gz
Source2:        my.cnf
Source3:        client.cnf

%if %{with testsuite}
Patch0001:      0001-testsuite.patch
%endif

BuildRequires:  libcurl-devel krb5-devel openssl-devel zlib-devel
BuildRequires:  gcc-c++ cmake
Requires:       %{_sysconfdir}/my.cnf

%description
MariaDB Connector/C is a C client library for MariaDB and MySQL databases.
It allows applications written in C/C++ to access MariaDB and MySQL databases using
the standard SQL language. The library provides a simple and efficient API for
connecting to and interacting with the database server. It is open source software
and is released under the LGPLv2.1 license. MariaDB Connector/C is compatible with
both MariaDB and MySQL databases, and it supports all major operating systems.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{EVR}
Recommends:     %{name}-doc = %{EVR}
Requires:       openssl-devel zlib-devel
Conflicts:      mysql-devel

%description devel
Development files for %{name}, containing everything needed to build against libmariadb.so >=3 client library.

%if %{with testsuite}
%package test
Summary:        Testsuite files for mariadb-connector-c
Requires:       %{name} = %{version}-%{release}
Requires:       cmake
Recommends:     mariadb-server

%description test
Testsuite files for mariadb-connector-c. Contains binaries and a prepared CMake ctest file.
Requires running MariaDB / MySQL server with create database "test".
%endif

%package config
Summary:        Configuration files for packages that use /etc/my.cnf as a configuration file
BuildArch:      noarch
Obsoletes:      mariadb-config <= 3:10.3.8-4

%description config
This package delivers /etc/my.cnf that includes other configuration files
from the /etc/my.cnf.d directory and ships this directory as well.
Other packages should only put their files into /etc/my.cnf.d directory
and require this package, so the /etc/my.cnf file is present.

%package doc
Summary:        Manual pages documenting API of the libmariadb.so library
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description doc
Manual pages documenting API of the libmariadb.so library for %{name}.

%prep
%setup -n %{name}-%{version}-src -q
%if %{with testsuite}
%patch1 -p1
%endif

rm -r win win-iconv zlib

%build
%cmake . -DCMAKE_BUILD_TYPE="%{?with_debug:Debug}%{!?with_debug:RelWithDebInfo}" \
       -DCMAKE_SYSTEM_PROCESSOR="%{_arch}" -DMARIADB_UNIX_ADDR=%{_sharedstatedir}/mysql/mysql.sock \
       -DMARIADB_PORT=3306 -DWITH_EXTERNAL_ZLIB=ON -DWITH_SSL=OPENSSL \
       -DWITH_MYSQLCOMPAT=ON -DPLUGIN_CLIENT_ED25519=DYNAMIC \
       -DINSTALL_LAYOUT=RPM -DINSTALL_BINDIR="bin" -DINSTALL_LIBDIR="%{_lib}" \
       -DINSTALL_INCLUDEDIR="include/mysql" -DINSTALL_PLUGINDIR="%{_lib}/mariadb/plugin" \
       -DINSTALL_PCDIR="%{_lib}/pkgconfig" \
\
%if %{with testsuite}
       -DWITH_UNIT_TESTS=ON
%endif

%if %{with debug}
CFLAGS="$CFLAGS     -O0 -g"; export CFLAGS
CXXFLAGS="$CXXFLAGS -O0 -g"; export CXXFLAGS
FFLAGS="$FFLAGS     -O0 -g"; export FFLAGS
FCFLAGS="$FCFLAGS   -O0 -g"; export FCFLAGS
%endif

cmake -B %__cmake_builddir -LAH

%cmake_build

%install
%cmake_install
rm %{buildroot}%{_libdir}/lib*.a
ln -s mariadb_config %{buildroot}%{_bindir}/mysql_config
ln -s mariadb_version.h %{buildroot}%{_includedir}/mysql/mysql_version.h
install -D -pm0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/my.cnf
install -D -pm0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/my.cnf.d/client.cnf

%generate_compatibility_deps

%check
%{buildroot}%{_bindir}/mariadb_config

%if %{with testsuite}
pushd unittest/libmariadb/
%ctest || :
popd
%endif

%files
%dir %{abidir}
%license COPYING.LIB
%{_libdir}/libmariadb.so.3
%dir %{_libdir}/mariadb
%dir %{_libdir}/mariadb/plugin
%{_libdir}/mariadb/plugin/*
%{abidir}/mariadb_config-option.list
%{abidir}/sha256_password.dump
%{abidir}/auth_gssapi_client.dump
%{abidir}/client_ed25519.dump
%{abidir}/dialog.dump
%{abidir}/libcctap.dump
%{abidir}/libmariadb.dump
%{abidir}/mysql_clear_password.dump
%{abidir}/remote_io.dump
%{abidir}/caching_sha2_password.dump
%{_mandir}/man3/{mariadb,mysql}_*.3*


%files devel
%{_bindir}/mysql_config
%{_bindir}/mariadb_config
%{_libdir}/pkgconfig/libmariadb.pc
%{_libdir}/libmysqlclient.so
%{_libdir}/libmysqlclient_r.so
%{_libdir}/libmariadb.so
%dir %{_includedir}/mysql
%{_includedir}/mysql/*

%files config
%dir %{_sysconfdir}/my.cnf.d
%config(noreplace) %{_sysconfdir}/my.cnf.d/client.cnf
%config(noreplace) %{_sysconfdir}/my.cnf

%if %{with testsuite}
%files test
%{_libdir}/libcctap.so
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%endif

%files doc
%doc README

%changelog
* Sat Apr 15 2023 Heng Qi <hengqi@linux.alibaba.com> -3.2.7-5
- Refator the spec file

* Mon Apr 03 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.2.7-4
- Del Specific Fields

* Tue Mar 28 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.2.7-3
- remove multilib related codes

* Wed Nov 02 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.2.7-2
- optimise spec file

* Thu Jun 30 2022 happy_orange <songnannan@linux.alibaba.com> - 3.2.7-1
- Init package from upstream release
